Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fcopy_dir.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fcopy_dir.sh	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fcopy_dir.sh	(revision 9573)
@@ -27,5 +27,5 @@
 #
 # When a reference configuration is set, 
-# Copy NEMO sub-directories needed (OPA_SRC, TOP_SRC ...)
+# Copy NEMO sub-directories needed (OCE_SRC, TOP_SRC ...)
 #
 # EXAMPLES
Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fcopy_extdir.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fcopy_extdir.sh	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fcopy_extdir.sh	(revision 9573)
@@ -18,5 +18,5 @@
 # ===========
 # When an unsupported configuration is requested, 
-# Prepare sources for the NEMO sub-directories needed (OPA_SRC, TOP_SRC ...)
+# Prepare sources for the NEMO sub-directories needed (OCE_SRC, TOP_SRC ...)
 # EXAMPLES
 # ========
Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fmake_WORK.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fmake_WORK.sh	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fmake_WORK.sh	(revision 9573)
@@ -45,5 +45,5 @@
 # ::
 #
-#  $ ./Fmake_WORK.sh ORCA2_LIM OPA_SRC LIM_SRC_2
+#  $ ./Fmake_WORK.sh ORCA2_LIM OCE_SRC ICE_SRC
 #
 #
@@ -89,6 +89,6 @@
 while [ $i -lt $NDIR ]
 do
-   [ "${ZTAB[i]}" = "OPA_SRC" ] && ln -sf ${NEMO_DIR}/OPA_SRC/*.[Ffh]90 ${ZCONF}/WORK
-   [ "${ZTAB[i]}" = "OPA_SRC" ] && ln -sf ${NEMO_DIR}/OPA_SRC/*/*.[Ffh]90 ${ZCONF}/WORK && break
+   [ "${ZTAB[i]}" = "OCE_SRC" ] && ln -sf ${NEMO_DIR}/OCE_SRC/*.[Ffh]90 ${ZCONF}/WORK
+   [ "${ZTAB[i]}" = "OCE_SRC" ] && ln -sf ${NEMO_DIR}/OCE_SRC/*/*.[Ffh]90 ${ZCONF}/WORK && break
    let i=$i+1
 done
@@ -97,5 +97,5 @@
 while [ $i -lt $NDIR ]
 do
-   if [ "${ZTAB[i]}" != "OPA_SRC" ]; then
+   if [ "${ZTAB[i]}" != "OCE_SRC" ]; then
       ln -sf ${NEMO_DIR}/${ZTAB[i]}/*.[Ffh]90 ${ZCONF}/WORK
       ln -sf ${NEMO_DIR}/${ZTAB[i]}/*/*.[Ffh]90 ${ZCONF}/WORK 
Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fprep_agrif.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fprep_agrif.sh	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/Fprep_agrif.sh	(revision 9573)
@@ -70,10 +70,10 @@
 
 #- AGRIF sources
-[ ! -d $2/$1/OPAFILES ] && mkdir  $2/$1/OPAFILES
-[ ! -d $2/$1/OPAFILES/AGRIF_INC ] && mkdir  $2/$1/OPAFILES/AGRIF_INC
-[ ! -d $2/$1/OPAFILES/AGRIF_MODELFILES ] && mkdir  $2/$1/OPAFILES/AGRIF_MODELFILES
-cp -f -r ${MAIN_DIR}/EXTERNAL/AGRIF/agrif_opa.in  $2/$1/OPAFILES/
-#cp -f -r ${MAIN_DIR}/EXTERNAL/AGRIF/conv  $2/$1/OPAFILES/
-cp -f -r $2/$1/AGRIFLIB/bin/conv  $2/$1/OPAFILES/
+[ ! -d $2/$1/NEMOFILES ] && mkdir  $2/$1/NEMOFILES
+[ ! -d $2/$1/NEMOFILES/AGRIF_INC ] && mkdir  $2/$1/NEMOFILES/AGRIF_INC
+[ ! -d $2/$1/NEMOFILES/AGRIF_MODELFILES ] && mkdir  $2/$1/NEMOFILES/AGRIF_MODELFILES
+cp -f -r ${MAIN_DIR}/EXTERNAL/AGRIF/agrif_oce.in  $2/$1/NEMOFILES/
+#cp -f -r ${MAIN_DIR}/EXTERNAL/AGRIF/conv  $2/$1/NEMOFILES/
+cp -f -r $2/$1/AGRIFLIB/bin/conv  $2/$1/NEMOFILES/
 
 fi
Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/bld.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/bld.cfg	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/bld.cfg	(revision 9573)
@@ -15,5 +15,5 @@
 src::ioipsl               $MAIN_DIR/EXTERNAL/IOIPSL/src
 src::agrif                $MAIN_DIR/EXTERNAL/AGRIF/AGRIF_FILES
-src::nemo                 $CONFIG_DIR/$NEW_CONF/OPAFILES/obj
+src::nemo                 $CONFIG_DIR/$NEW_CONF/NEMOFILES/obj
 
 bld::target  nemo.exe
@@ -39,5 +39,5 @@
 bld::pp::nemo     1
 bld::pp::agrif    1
-bld::tool::fppflags::nemo      %FPPFLAGS -I$CONFIG_DIR/$NEW_CONF/OPAFILES/inc
+bld::tool::fppflags::nemo      %FPPFLAGS -I$CONFIG_DIR/$NEW_CONF/NEMOFILES/inc
 bld::tool::fppflags::ioipsl    %FPPFLAGS
 bld::tool::fppflags::agrif     %FPPFLAGS -include ${MAIN_DIR}/EXTERNAL/AGRIF/nemo_mpi.h
Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/bld_preproagr.cfg
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/bld_preproagr.cfg	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/bld_preproagr.cfg	(revision 9573)
@@ -16,5 +16,5 @@
 bld::target  lib_cray.f90 nemo.f90 agrif_user.f90 agrif2model.f90 
 
-dir::root            $NEMO_TDIR/$NEW_CONF/OPAFILES
+dir::root            $NEMO_TDIR/$NEW_CONF/NEMOFILES
 
 bld::tool::fc_output
Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/DOMAINcfg/README_configs_namcfg_namdom
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/DOMAINcfg/README_configs_namcfg_namdom	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/DOMAINcfg/README_configs_namcfg_namdom	(revision 9573)
@@ -2,5 +2,5 @@
 
 This README file contains the informations for the &namcfg namelist for some configurations whic are not one of the reference configurations.
-These informations wher previoulsy in NEMO/OPA_SRC_par_*.h90 files. The full test with these configurations has not been done.
+These informations wher previoulsy in NEMO/OCE_SRC_par_*.h90 files. The full test with these configurations has not been done.
 
 
Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/MISCELLANEOUS/chk_iomput.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/MISCELLANEOUS/chk_iomput.sh	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/MISCELLANEOUS/chk_iomput.sh	(revision 9573)
@@ -37,5 +37,5 @@
 	    echo '      ./chk_iomput.sh'
 	    echo '      ./chk_iomput.sh --help'
-	    echo '      ./chk_iomput.sh ../../CONFIG/ORCA2_LIM/EXP00/context_nemo.xml "../../NEMO/OPA_SRC/ ../../NEMO/LIM_SRC_2/"'
+	    echo '      ./chk_iomput.sh ../../CONFIG/ORCA2_LIM/EXP00/context_nemo.xml "../../NEMO/OCE_SRC/ ../../NEMO/ICE_SRC/"'
 	    echo
 	    exit ;;
Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/SIREN/src/docsrc/2_quickstart.md
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/SIREN/src/docsrc/2_quickstart.md	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/SIREN/src/docsrc/2_quickstart.md	(revision 9573)
@@ -705,5 +705,5 @@
 To do so, go to the directory *NEMOGCM/CONFIG/*, and run:
 ~~~~~~~~~~~~~~~~~~
-./makenemo -n MY_CONFIG -d "OPA_SRC"
+./makenemo -n MY_CONFIG -d "OCE_SRC"
 ~~~~~~~~~~~~~~~~~~
 This creates your configuration "MY_CONFIG" in the directory *NEMOGCM/CONFIG*.<br/>

Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/agrifpp.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/agrifpp.sh	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/COMPILE/agrifpp.sh	(revision 9573)
@@ -26,8 +26,8 @@
 #
 #
 # Preprocess file using the conv in OPAFILES directory
 # Standard preprocessed files are stored in OPAFILES/ppsrc/nemo
 # Source files are stored under OPAFILES/obj
 # Include filess  in OPAFILES/inc
 # Note that agrif2model.F90 should not be preprocess (standard one) 
 #
@@ -57,6 +57,6 @@
 MYFILE=$(basename "$1")
 if [ "$MYFILE" == "agrif2model.f90" ];then
-   \cp ${NEMO_TDIR}/${NEW_CONF}/WORK/${MYFILE/.f90/.F90} ${NEMO_TDIR}/${NEW_CONF}/OPAFILES/obj/$MYFILE
+   \cp ${NEMO_TDIR}/${NEW_CONF}/WORK/${MYFILE/.f90/.F90} ${NEMO_TDIR}/${NEW_CONF}/NEMOFILES/obj/$MYFILE
 else
-cd ${NEMO_TDIR}/${NEW_CONF}/OPAFILES/ppsrc/nemo ; ${NEMO_TDIR}/${NEW_CONF}/OPAFILES/conv ${NEMO_TDIR}/${NEW_CONF}/OPAFILES/agrif_opa.in -rm -incdir ${NEMO_TDIR}/${NEW_CONF}/OPAFILES/inc -comdirout ${NEMO_TDIR}/${NEW_CONF}/OPAFILES/obj -convfile ${MYFILE} > /dev/null 
+cd ${NEMO_TDIR}/${NEW_CONF}/NEMOFILES/ppsrc/nemo ; ${NEMO_TDIR}/${NEW_CONF}/NEMOFILES/conv ${NEMO_TDIR}/${NEW_CONF}/NEMOFILES/agrif_oce.in -rm -incdir ${NEMO_TDIR}/${NEW_CONF}/NEMOFILES/inc -comdirout ${NEMO_TDIR}/${NEW_CONF}/NEMOFILES/obj -convfile ${MYFILE} > /dev/null 
 fi
@@ -26,8 +26,8 @@
 #
 #
-# Preprocess file using the conv in OPAFILES directory
-# Standard preprocessed files are stored in OPAFILES/ppsrc/nemo
-# Source files are stored under OPAFILES/obj
-# Include filess  in OPAFILES/inc
+# Preprocess file using the conv in NEMOFILES directory
+# Standard preprocessed files are stored in NEMOFILES/ppsrc/nemo
+# Source files are stored under NEMOFILES/obj
+# Include filess  in NEMOFILES/inc
 # Note that agrif2model.F90 should not be preprocess (standard one) 
 #
Index: /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/MISCELLANEOUS/rewrite_nemo.sh
===================================================================
--- /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/MISCELLANEOUS/rewrite_nemo.sh	(revision 9572)
+++ /branches/2017/dev_merge_2017/NEMOGCM/TOOLS/MISCELLANEOUS/rewrite_nemo.sh	(revision 9573)
@@ -136,55 +136,55 @@
 # some specific changes...
 #
-# OPA_SRC/SBC/albedo.F90
-sed -e "s/DIMENSION(jpi,jpj,ijpl/DIMENSION(jpi,jpj,SIZE(pt_ice,3)/" OPA_SRC/SBC/albedo.F90 > tmp$$
-mv tmp$$ OPA_SRC/SBC/albedo.F90
+# OCE_SRC/SBC/albedo.F90
+sed -e "s/DIMENSION(jpi,jpj,ijpl/DIMENSION(jpi,jpj,SIZE(pt_ice,3)/" OCE_SRC/SBC/albedo.F90 > tmp$$
+mv tmp$$ OCE_SRC/SBC/albedo.F90
 # see result of
 #    grep -i "wrk_alloc" $( find . -name "*90" ) | grep "="
 #
-# LIM_SRC_2/limrhg_2.F90
-#./LIM_SRC_2/limrhg_2.F90:      CALL wrk_alloc( jpi,jpj+2, zu0, zv0, zu_n, zv_n, zu_a, zv_a, zviszeta, zviseta, kjstart = 0 )
-#./LIM_SRC_2/limrhg_2.F90:      CALL wrk_alloc( jpi,jpj+2, zzfrld, zztms, zi1, zi2, zmasst, zpresh, kjstart = 0 )
-sed -e "s/DIMENSION(jpi,jpj+2/DIMENSION(jpi,0:jpj+1/" LIM_SRC_2/limrhg_2.F90 > tmp$$
-mv tmp$$ LIM_SRC_2/limrhg_2.F90
-
-# LIM_SRC_3/limitd_me.F90
-#./LIM_SRC_3/limitd_me.F90:      CALL wrk_alloc( jpi,jpj,jpl+2, Gsum, kkstart = -1 )
-sed -e "s/DIMENSION(jpi,jpj,jpl+2)/DIMENSION(jpi,jpj,-1:jpl)/" LIM_SRC_3/limitd_me.F90 > tmp$$
-mv tmp$$ LIM_SRC_3/limitd_me.F90
-
-# LIM_SRC_3/limitd_th.F90
-#./LIM_SRC_3/limitd_th.F90:      CALL wrk_alloc( jpi,jpj,jpl+1, zhbnew, kkstart = 0 )   
-sed -e "s/DIMENSION(jpi,jpj,jpl+1)/DIMENSION(jpi,jpj,0:jpl)/" LIM_SRC_3/limitd_th.F90 > tmp$$
-mv tmp$$ LIM_SRC_3/limitd_th.F90
-
-# LIM_SRC_3/limthd_dif.F90
-#./LIM_SRC_3/limthd_dif.F90:      CALL wrk_alloc( jpij,nlay_i+1, ztcond_i, zradtr_i, zradab_i, zkappa_i, ztib, zeta_i, ztitemp, z_i, zspeche_i, kjstart=0 )
-#./LIM_SRC_3/limthd_dif.F90:      CALL wrk_alloc( jpij,nlay_s+1,           zradtr_s, zradab_s, zkappa_s, ztsb, zeta_s, ztstemp, z_s, kjstart=0 )
+# ICE_SRC/limrhg_2.F90
+#./ICE_SRC/limrhg_2.F90:      CALL wrk_alloc( jpi,jpj+2, zu0, zv0, zu_n, zv_n, zu_a, zv_a, zviszeta, zviseta, kjstart = 0 )
+#./ICE_SRC/limrhg_2.F90:      CALL wrk_alloc( jpi,jpj+2, zzfrld, zztms, zi1, zi2, zmasst, zpresh, kjstart = 0 )
+sed -e "s/DIMENSION(jpi,jpj+2/DIMENSION(jpi,0:jpj+1/" ICE_SRC/limrhg_2.F90 > tmp$$
+mv tmp$$ ICE_SRC/limrhg_2.F90
+
+# ICE_SRC/limitd_me.F90
+#./ICE_SRC/limitd_me.F90:      CALL wrk_alloc( jpi,jpj,jpl+2, Gsum, kkstart = -1 )
+sed -e "s/DIMENSION(jpi,jpj,jpl+2)/DIMENSION(jpi,jpj,-1:jpl)/" ICE_SRC/limitd_me.F90 > tmp$$
+mv tmp$$ ICE_SRC/limitd_me.F90
+
+# ICE_SRC/limitd_th.F90
+#./ICE_SRC/limitd_th.F90:      CALL wrk_alloc( jpi,jpj,jpl+1, zhbnew, kkstart = 0 )   
+sed -e "s/DIMENSION(jpi,jpj,jpl+1)/DIMENSION(jpi,jpj,0:jpl)/" ICE_SRC/limitd_th.F90 > tmp$$
+mv tmp$$ ICE_SRC/limitd_th.F90
+
+# ICE_SRC/limthd_dif.F90
+#./ICE_SRC/limthd_dif.F90:      CALL wrk_alloc( jpij,nlay_i+1, ztcond_i, zradtr_i, zradab_i, zkappa_i, ztib, zeta_i, ztitemp, z_i, zspeche_i, kjstart=0 )
+#./ICE_SRC/limthd_dif.F90:      CALL wrk_alloc( jpij,nlay_s+1,           zradtr_s, zradab_s, zkappa_s, ztsb, zeta_s, ztstemp, z_s, kjstart=0 )
 sed -e "s/DIMENSION(kiut,nlay_i+1)/DIMENSION(kiut,0:nlay_i)/" \
-    -e "s/DIMENSION(kiut,nlay_s+1)/DIMENSION(kiut,0:nlay_s)/" LIM_SRC_3/limthd_dif.F90 > tmp$$
-mv tmp$$ LIM_SRC_3/limthd_dif.F90
-
-# LIM_SRC_3/limthd_ent.F90
-#./LIM_SRC_3/limthd_ent.F90:      CALL wrk_alloc( jpij, nlay_i+3, zqh_cum0, zh_cum0, kjstart = 0 )
-#./LIM_SRC_3/limthd_ent.F90:      CALL wrk_alloc( jpij, nlay_i+1, zqh_cum1, zh_cum1, kjstart = 0 )
+    -e "s/DIMENSION(kiut,nlay_s+1)/DIMENSION(kiut,0:nlay_s)/" ICE_SRC/limthd_dif.F90 > tmp$$
+mv tmp$$ ICE_SRC/limthd_dif.F90
+
+# ICE_SRC/limthd_ent.F90
+#./ICE_SRC/limthd_ent.F90:      CALL wrk_alloc( jpij, nlay_i+3, zqh_cum0, zh_cum0, kjstart = 0 )
+#./ICE_SRC/limthd_ent.F90:      CALL wrk_alloc( jpij, nlay_i+1, zqh_cum1, zh_cum1, kjstart = 0 )
 sed -e "s/DIMENSION(jpij,nlay_i+3)/DIMENSION(jpij,0:nlay_i+2)/" \
-    -e "s/DIMENSION(jpij,nlay_i+1)/DIMENSION(jpij,0:nlay_i)/" LIM_SRC_3/limthd_ent.F90 > tmp$$
-mv tmp$$ LIM_SRC_3/limthd_ent.F90
-
-# OPA_SRC/DYN/divcur.F90
-#./OPA_SRC/DYN/divcur.F90:      CALL wrk_alloc( jpi+4, jpj  , zwv, kjstart = -1 )
-sed -e "s/DIMENSION(jpi+4,jpj)/DIMENSION(-1:jpi+2,jpj)/" OPA_SRC/DYN/divcur.F90 > tmp$$
-mv tmp$$ OPA_SRC/DYN/divcur.F90
-
-# OPA_SRC/LDF/ldfslp.F90
-#./OPA_SRC/LDF/ldfslp.F90:      CALL wrk_alloc( jpi,jpj,jpk,2, zdxrho , zdyrho, zdzrho,              klstart = 0  )
-#./OPA_SRC/LDF/ldfslp.F90:      CALL wrk_alloc( jpi,jpj,  2,2, zti_mlb, ztj_mlb,        kkstart = 0, klstart = 0  )
+    -e "s/DIMENSION(jpij,nlay_i+1)/DIMENSION(jpij,0:nlay_i)/" ICE_SRC/limthd_ent.F90 > tmp$$
+mv tmp$$ ICE_SRC/limthd_ent.F90
+
+# OCE_SRC/DYN/divcur.F90
+#./OCE_SRC/DYN/divcur.F90:      CALL wrk_alloc( jpi+4, jpj  , zwv, kjstart = -1 )
+sed -e "s/DIMENSION(jpi+4,jpj)/DIMENSION(-1:jpi+2,jpj)/" OCE_SRC/DYN/divcur.F90 > tmp$$
+mv tmp$$ OCE_SRC/DYN/divcur.F90
+
+# OCE_SRC/LDF/ldfslp.F90
+#./OCE_SRC/LDF/ldfslp.F90:      CALL wrk_alloc( jpi,jpj,jpk,2, zdxrho , zdyrho, zdzrho,              klstart = 0  )
+#./OCE_SRC/LDF/ldfslp.F90:      CALL wrk_alloc( jpi,jpj,  2,2, zti_mlb, ztj_mlb,        kkstart = 0, klstart = 0  )
 sed -e "s/DIMENSION(jpi,jpj,jpk,2)/DIMENSION(jpi,jpj,jpk,0:1)/" \
-    -e "s/DIMENSION(jpi,jpj,2,2)/DIMENSION(jpi,jpj,0:1,0:1)/" OPA_SRC/LDF/ldfslp.F90 > tmp$$
-mv tmp$$ OPA_SRC/LDF/ldfslp.F90
-# OPA_SRC/ZDF/zdfkpp.F90
-#./OPA_SRC/ZDF/zdfkpp.F90:      CALL wrk_alloc( jpi,3, zmoek, kjstart = 0 )
-sed -e "s/DIMENSION(jpi,3) *::* zmoek/DIMENSION(jpi,0:2) ::   zmoek/" OPA_SRC/ZDF/zdfkpp.F90 > tmp$$
-mv tmp$$ OPA_SRC/ZDF/zdfkpp.F90
+    -e "s/DIMENSION(jpi,jpj,2,2)/DIMENSION(jpi,jpj,0:1,0:1)/" OCE_SRC/LDF/ldfslp.F90 > tmp$$
+mv tmp$$ OCE_SRC/LDF/ldfslp.F90
+# OCE_SRC/ZDF/zdfkpp.F90
+#./OCE_SRC/ZDF/zdfkpp.F90:      CALL wrk_alloc( jpi,3, zmoek, kjstart = 0 )
+sed -e "s/DIMENSION(jpi,3) *::* zmoek/DIMENSION(jpi,0:2) ::   zmoek/" OCE_SRC/ZDF/zdfkpp.F90 > tmp$$
+mv tmp$$ OCE_SRC/ZDF/zdfkpp.F90
 
 # links 
@@ -192,7 +192,7 @@
 # find . -type l
 #
-# ./LIM_SRC_2/limrhg.F90
-cd LIM_SRC_2
-ln -sf ../LIM_SRC_3/limrhg.F90 .
+# ./ICE_SRC/limrhg.F90
+cd ICE_SRC
+ln -sf ../ICE_SRC/limrhg.F90 .
 cd ..
 
@@ -204,4 +204,4 @@
 # ./OOO_SRC/obs_fbm.F90
 cd OOO_SRC
-ln -sf ../OPA_SRC/OBS/obs_fbm.F90 .
+ln -sf ../OCE_SRC/OBS/obs_fbm.F90 .
 cd ..